pub struct Standard<T>(/* private fields */);Expand description
Typed standard arithmetic algebra (add = +, mul = *).
The type parameter T carries the scalar type, making the algebra
Alg::Scalar-centric. This is the canonical core model — HasAlgebra
provides UX sugar for automatic inference (e.g., f64 → Standard<f64>).
This is the default algebra for built-in numeric types (f32, f64,
Complex32, Complex64).
Examples
use tenferro_algebra::{HasAlgebra, Standard};
// f64 maps to Standard<f64> algebra automatically
fn check_algebra<T: HasAlgebra<Algebra = Standard<T>>>() {}
check_algebra::<f64>();
check_algebra::<f32>();Trait Implementations
Sourceimpl<T> Semiring for Standard<T>
Standard arithmetic implements Semiring with + and *.
impl<T> Semiring for Standard<T>
Standard arithmetic implements Semiring with + and *.
Examples
use tenferro_algebra::{Semiring, Standard};
let z = <Standard<f64> as Semiring>::zero();
let o = <Standard<f64> as Semiring>::one();
assert_eq!(z, 0.0);
assert_eq!(o, 1.0);Sourceimpl<S> TensorAnalyticPrims<Standard<S>> for CpuBackendwhere
S: Scalar + 'static,
impl<S> TensorAnalyticPrims<Standard<S>> for CpuBackendwhere
S: Scalar + 'static,
type Plan = CpuAnalyticPlan
type Context = CpuContext
Sourcefn plan(
_ctx: &mut <CpuBackend as TensorAnalyticPrims<Standard<S>>>::Context,
desc: &AnalyticPrimsDescriptor,
shapes: &[&[usize]],
) -> Result<<CpuBackend as TensorAnalyticPrims<Standard<S>>>::Plan, Error>
fn plan( _ctx: &mut <CpuBackend as TensorAnalyticPrims<Standard<S>>>::Context, desc: &AnalyticPrimsDescriptor, shapes: &[&[usize]], ) -> Result<<CpuBackend as TensorAnalyticPrims<Standard<S>>>::Plan, Error>
Plan an analytic-family operation for the given input/output shapes. Read more
Sourcefn execute(
_ctx: &mut <CpuBackend as TensorAnalyticPrims<Standard<S>>>::Context,
plan: &<CpuBackend as TensorAnalyticPrims<Standard<S>>>::Plan,
alpha: S,
inputs: &[&Tensor<S>],
beta: S,
output: &mut Tensor<S>,
) -> Result<(), Error>
fn execute( _ctx: &mut <CpuBackend as TensorAnalyticPrims<Standard<S>>>::Context, plan: &<CpuBackend as TensorAnalyticPrims<Standard<S>>>::Plan, alpha: S, inputs: &[&Tensor<S>], beta: S, output: &mut Tensor<S>, ) -> Result<(), Error>
Execute a previously planned analytic-family operation. Read more
Sourcefn has_analytic_support(desc: AnalyticPrimsDescriptor) -> bool
fn has_analytic_support(desc: AnalyticPrimsDescriptor) -> bool
Report whether the backend advertises support for the given descriptor. Read more
Sourceimpl<S> TensorIndexingPrims<Standard<S>> for CpuBackendwhere
S: Scalar + 'static,
impl<S> TensorIndexingPrims<Standard<S>> for CpuBackendwhere
S: Scalar + 'static,
Sourcetype Plan = CpuIndexingPlan
type Plan = CpuIndexingPlan
Backend-specific execution plan.
Sourcetype Context = CpuContext
type Context = CpuContext
Backend execution context.
Sourcefn plan(
_ctx: &mut <CpuBackend as TensorIndexingPrims<Standard<S>>>::Context,
desc: &IndexingPrimsDescriptor,
shapes: &[&[usize]],
) -> Result<<CpuBackend as TensorIndexingPrims<Standard<S>>>::Plan, Error>
fn plan( _ctx: &mut <CpuBackend as TensorIndexingPrims<Standard<S>>>::Context, desc: &IndexingPrimsDescriptor, shapes: &[&[usize]], ) -> Result<<CpuBackend as TensorIndexingPrims<Standard<S>>>::Plan, Error>
Plan an indexing operation for the given input/index/output shapes. Read more
Sourcefn execute(
_ctx: &mut <CpuBackend as TensorIndexingPrims<Standard<S>>>::Context,
plan: &<CpuBackend as TensorIndexingPrims<Standard<S>>>::Plan,
inputs: &[&Tensor<S>],
indices: &Tensor<i64>,
output: &mut Tensor<S>,
) -> Result<(), Error>
fn execute( _ctx: &mut <CpuBackend as TensorIndexingPrims<Standard<S>>>::Context, plan: &<CpuBackend as TensorIndexingPrims<Standard<S>>>::Plan, inputs: &[&Tensor<S>], indices: &Tensor<i64>, output: &mut Tensor<S>, ) -> Result<(), Error>
Execute a previously planned indexing operation. Read more
Sourcefn has_indexing_support(_desc: IndexingPrimsDescriptor) -> bool
fn has_indexing_support(_desc: IndexingPrimsDescriptor) -> bool
Report whether the backend advertises support for the given descriptor.
Sourceimpl TensorRngPrims<Standard<f64>> for CpuBackend
impl TensorRngPrims<Standard<f64>> for CpuBackend
Sourcetype Context = CpuContext
type Context = CpuContext
Backend execution context.
Sourcefn plan(
_ctx: &mut <CpuBackend as TensorRngPrims<Standard<f64>>>::Context,
desc: &RngPrimsDescriptor,
shapes: &[&[usize]],
) -> Result<<CpuBackend as TensorRngPrims<Standard<f64>>>::Plan, Error>
fn plan( _ctx: &mut <CpuBackend as TensorRngPrims<Standard<f64>>>::Context, desc: &RngPrimsDescriptor, shapes: &[&[usize]], ) -> Result<<CpuBackend as TensorRngPrims<Standard<f64>>>::Plan, Error>
Plan a tensor RNG operation for the given output shape.
Sourcefn execute(
_ctx: &mut <CpuBackend as TensorRngPrims<Standard<f64>>>::Context,
plan: &<CpuBackend as TensorRngPrims<Standard<f64>>>::Plan,
generator: &mut Generator,
output: &mut Tensor<f64>,
) -> Result<(), Error>
fn execute( _ctx: &mut <CpuBackend as TensorRngPrims<Standard<f64>>>::Context, plan: &<CpuBackend as TensorRngPrims<Standard<f64>>>::Plan, generator: &mut Generator, output: &mut Tensor<f64>, ) -> Result<(), Error>
Execute a previously planned RNG operation.
Sourcefn has_rng_support(desc: RngPrimsDescriptor) -> bool
fn has_rng_support(desc: RngPrimsDescriptor) -> bool
Report whether the backend advertises support for the given descriptor.
Sourceimpl TensorRngPrims<Standard<i32>> for CpuBackend
impl TensorRngPrims<Standard<i32>> for CpuBackend
Sourcetype Context = CpuContext
type Context = CpuContext
Backend execution context.
Sourcefn plan(
_ctx: &mut <CpuBackend as TensorRngPrims<Standard<i32>>>::Context,
desc: &RngPrimsDescriptor,
shapes: &[&[usize]],
) -> Result<<CpuBackend as TensorRngPrims<Standard<i32>>>::Plan, Error>
fn plan( _ctx: &mut <CpuBackend as TensorRngPrims<Standard<i32>>>::Context, desc: &RngPrimsDescriptor, shapes: &[&[usize]], ) -> Result<<CpuBackend as TensorRngPrims<Standard<i32>>>::Plan, Error>
Plan a tensor RNG operation for the given output shape.
Sourcefn execute(
_ctx: &mut <CpuBackend as TensorRngPrims<Standard<i32>>>::Context,
plan: &<CpuBackend as TensorRngPrims<Standard<i32>>>::Plan,
generator: &mut Generator,
output: &mut Tensor<i32>,
) -> Result<(), Error>
fn execute( _ctx: &mut <CpuBackend as TensorRngPrims<Standard<i32>>>::Context, plan: &<CpuBackend as TensorRngPrims<Standard<i32>>>::Plan, generator: &mut Generator, output: &mut Tensor<i32>, ) -> Result<(), Error>
Execute a previously planned RNG operation.
Sourcefn has_rng_support(desc: RngPrimsDescriptor) -> bool
fn has_rng_support(desc: RngPrimsDescriptor) -> bool
Report whether the backend advertises support for the given descriptor.
Sourceimpl<S> TensorScalarPrims<Standard<S>> for CpuBackendwhere
S: Scalar + 'static,
impl<S> TensorScalarPrims<Standard<S>> for CpuBackendwhere
S: Scalar + 'static,
type Plan = CpuScalarPlan
type Context = CpuContext
Sourcefn plan(
_ctx: &mut <CpuBackend as TensorScalarPrims<Standard<S>>>::Context,
desc: &ScalarPrimsDescriptor,
shapes: &[&[usize]],
) -> Result<<CpuBackend as TensorScalarPrims<Standard<S>>>::Plan, Error>
fn plan( _ctx: &mut <CpuBackend as TensorScalarPrims<Standard<S>>>::Context, desc: &ScalarPrimsDescriptor, shapes: &[&[usize]], ) -> Result<<CpuBackend as TensorScalarPrims<Standard<S>>>::Plan, Error>
Plan a scalar-family operation for the given input/output shapes. Read more
Sourcefn execute(
_ctx: &mut <CpuBackend as TensorScalarPrims<Standard<S>>>::Context,
plan: &<CpuBackend as TensorScalarPrims<Standard<S>>>::Plan,
alpha: S,
inputs: &[&Tensor<S>],
beta: S,
output: &mut Tensor<S>,
) -> Result<(), Error>
fn execute( _ctx: &mut <CpuBackend as TensorScalarPrims<Standard<S>>>::Context, plan: &<CpuBackend as TensorScalarPrims<Standard<S>>>::Plan, alpha: S, inputs: &[&Tensor<S>], beta: S, output: &mut Tensor<S>, ) -> Result<(), Error>
Execute a previously planned scalar-family operation. Read more
Sourcefn has_scalar_support(desc: ScalarPrimsDescriptor) -> bool
fn has_scalar_support(desc: ScalarPrimsDescriptor) -> bool
Report whether the backend advertises support for the given descriptor. Read more
Sourceimpl<S> TensorSemiringCore<Standard<S>> for CpuBackendwhere
S: Scalar,
impl<S> TensorSemiringCore<Standard<S>> for CpuBackendwhere
S: Scalar,
Sourcetype Context = CpuContext
type Context = CpuContext
Backend-specific execution context.
Sourcefn plan(
ctx: &mut CpuContext,
desc: &SemiringCoreDescriptor,
shapes: &[&[usize]],
) -> Result<CpuPlan<S>, Error>
fn plan( ctx: &mut CpuContext, desc: &SemiringCoreDescriptor, shapes: &[&[usize]], ) -> Result<CpuPlan<S>, Error>
Plan a semiring-core operation.
Sourceimpl<S> TensorSemiringFastPath<Standard<S>> for CpuBackendwhere
S: Scalar,
impl<S> TensorSemiringFastPath<Standard<S>> for CpuBackendwhere
S: Scalar,
Sourcetype Context = CpuContext
type Context = CpuContext
Backend-specific execution context.
Sourcefn plan(
ctx: &mut CpuContext,
desc: &SemiringFastPathDescriptor,
shapes: &[&[usize]],
) -> Result<CpuPlan<S>, Error>
fn plan( ctx: &mut CpuContext, desc: &SemiringFastPathDescriptor, shapes: &[&[usize]], ) -> Result<CpuPlan<S>, Error>
Plan an optional semiring fast path.
Sourcefn execute(
ctx: &mut CpuContext,
plan: &CpuPlan<S>,
alpha: S,
inputs: &[&Tensor<S>],
beta: S,
output: &mut Tensor<S>,
) -> Result<(), Error>
fn execute( ctx: &mut CpuContext, plan: &CpuPlan<S>, alpha: S, inputs: &[&Tensor<S>], beta: S, output: &mut Tensor<S>, ) -> Result<(), Error>
Execute an optional semiring fast path.
Sourcefn has_fast_path(desc: SemiringFastPathDescriptor) -> bool
fn has_fast_path(desc: SemiringFastPathDescriptor) -> bool
Query whether the optional path is available.
Sourceimpl<S> TensorSortPrims<Standard<S>> for CpuBackendwhere
S: Scalar + PartialOrd + 'static,
impl<S> TensorSortPrims<Standard<S>> for CpuBackendwhere
S: Scalar + PartialOrd + 'static,
Sourcetype Plan = CpuSortPlan
type Plan = CpuSortPlan
Backend-specific execution plan.
Sourcetype Context = CpuContext
type Context = CpuContext
Backend execution context.
Sourcefn plan(
_ctx: &mut <CpuBackend as TensorSortPrims<Standard<S>>>::Context,
desc: &SortPrimsDescriptor,
shapes: &[&[usize]],
) -> Result<<CpuBackend as TensorSortPrims<Standard<S>>>::Plan, Error>
fn plan( _ctx: &mut <CpuBackend as TensorSortPrims<Standard<S>>>::Context, desc: &SortPrimsDescriptor, shapes: &[&[usize]], ) -> Result<<CpuBackend as TensorSortPrims<Standard<S>>>::Plan, Error>
Plan a sort operation for the given input shape. Read more
Sourcefn execute(
_ctx: &mut <CpuBackend as TensorSortPrims<Standard<S>>>::Context,
plan: &<CpuBackend as TensorSortPrims<Standard<S>>>::Plan,
input: &Tensor<S>,
values_out: &mut Tensor<S>,
indices_out: &mut Tensor<i64>,
) -> Result<(), Error>
fn execute( _ctx: &mut <CpuBackend as TensorSortPrims<Standard<S>>>::Context, plan: &<CpuBackend as TensorSortPrims<Standard<S>>>::Plan, input: &Tensor<S>, values_out: &mut Tensor<S>, indices_out: &mut Tensor<i64>, ) -> Result<(), Error>
Execute a previously planned sort operation. Read more
Sourcefn has_sort_support(_desc: &SortPrimsDescriptor) -> bool
fn has_sort_support(_desc: &SortPrimsDescriptor) -> bool
Report whether the backend advertises support for the given descriptor.